@@ -1,14 +1,14 @@
-from .category import RibbonCategory, CategoryStyle, RibbonNormalCategory, RibbonContextCategory
+from .category import RibbonCategory, RibbonCategoryStyle, RibbonNormalCategory, RibbonContextCategory
 from .categorylayoutwidget import (RibbonCategoryLayoutWidget, RibbonCategoryLayoutButton, RibbonCategoryScrollArea,
                                    RibbonCategoryScrollAreaContents)
 from .gallery import RibbonGallery, RibbonGalleryListWidget, RibbonGalleryButton, RibbonGalleryPopupListWidget
 from .mainwindow import RibbonMainWindow
-from .panel import RibbonPanel, RibbonPanelTitle, SpaceFindMode, GridLayoutManager, RibbonPanelItemWidget
-from .panel import SpaceFindMode
+from .panel import RibbonPanel, RibbonPanelTitle, RibbonSpaceFindMode, RibbonGridLayoutManager, RibbonPanelItemWidget
+from .panel import RibbonSpaceFindMode
 from .ribbonbar import RibbonBar, RibbonStyle
 from .separator import RibbonSeparator, RibbonHorizontalSeparator, RibbonVerticalSeparator
 from .tabbar import RibbonTabBar
 from .titlewidget import RibbonTitleWidget, RibbonApplicationButton, RibbonTitleLabel
-from .toolbutton import RibbonToolButton, ButtonStyle
+from .toolbutton import RibbonToolButton, RibbonButtonStyle
 
 __version__ = "0.1.0"
