@@ -6,7 +6,7 @@ from PyQt5 import QtWidgets, QtGui, QtCore
 
 from .gallery import RibbonGallery
 from .separator import RibbonHorizontalSeparator, RibbonVerticalSeparator
-from .toolbutton import RibbonToolButton, ButtonStyle
+from .toolbutton import RibbonToolButton, RibbonButtonStyle
 from .utils import data_file_path
 
 
@@ -15,13 +15,13 @@ class RibbonPanelTitle(QtWidgets.QLabel):
     pass
 
 
-class SpaceFindMode(IntEnum):
+class RibbonSpaceFindMode(IntEnum):
     """Mode to find available space in a grid layout, ColumnWise or RowWise."""
     ColumnWise = 0
     RowWise = 1
 
 
-class GridLayoutManager(object):
+class RibbonGridLayoutManager(object):
     """Grid Layout Manager."""
 
     def __init__(self, rows: int):
@@ -32,7 +32,7 @@ class GridLayoutManager(object):
         self.rows = rows
         self.cells = np.ones((rows, 1), dtype=bool)
 
-    def request_cells(self, rowSpan: int = 1, colSpan: int = 1, mode=SpaceFindMode.ColumnWise):
+    def request_cells(self, rowSpan: int = 1, colSpan: int = 1, mode=RibbonSpaceFindMode.ColumnWise):
         """Request a number of available cells from the grid.
 
         :param rowSpan: The number of rows the cell should span.
@@ -42,7 +42,7 @@ class GridLayoutManager(object):
         """
         if rowSpan > self.rows:
             raise ValueError("RowSpan is too large")
-        if mode == SpaceFindMode.ColumnWise:
+        if mode == RibbonSpaceFindMode.ColumnWise:
             for row in range(self.cells.shape[0] - rowSpan + 1):
                 for col in range(self.cells.shape[1] - colSpan + 1):
                     if self.cells[row: row + rowSpan, col: col + colSpan].all():
@@ -104,7 +104,7 @@ class RibbonPanel(QtWidgets.QFrame):
     #: maximal number of rows
     _maxRows: int
     #: GridLayout manager to request available cells.
-    _gridLayoutManager: GridLayoutManager
+    _gridLayoutManager: RibbonGridLayoutManager
 
     #: widgets that are added to the panel
     _widgets: typing.List[QtWidgets.QWidget] = []
@@ -124,7 +124,7 @@ class RibbonPanel(QtWidgets.QFrame):
         """
         super().__init__(parent)
         self._maxRows = maxRows
-        self._gridLayoutManager = GridLayoutManager(self._maxRows)
+        self._gridLayoutManager = RibbonGridLayoutManager(self._maxRows)
         self._widgets = []
 
         # Main layout
@@ -133,7 +133,6 @@ class RibbonPanel(QtWidgets.QFrame):
         self._mainLayout.setSpacing(5)
 
         # Actions layout
-        # self._actionsWidget = QtWidgets.QWidget(self)
         self._actionsLayout = QtWidgets.QGridLayout()
         self._actionsLayout.setContentsMargins(5, 0, 5, 0)
         self._actionsLayout.setSpacing(5)
@@ -153,11 +152,26 @@ class RibbonPanel(QtWidgets.QFrame):
         self._panelOption.setAutoRaise(True)
         self._panelOption.setIcon(QtGui.QIcon(data_file_path("icons/linking.png")))
         self._panelOption.setIconSize(QtCore.QSize(16, 16))
+        self._panelOption.setToolTip("Panel options")
         self._panelOption.clicked.connect(self.panelOptionClicked)
         self._titleLayout.addWidget(self._panelOption, 0)
 
         self._mainLayout.addWidget(self._titleWidget, 0)
 
+    def panelOptionButton(self) -> RibbonPanelOptionButton:
+        """Return the panel option button.
+
+        :return: The panel option button.
+        """
+        return self._panelOption
+
+    def setPanelOptionToolTip(self, text: str):
+        """Set the tooltip of the panel option button.
+
+        :param text: The tooltip text.
+        """
+        self._panelOption.setToolTip(text)
+
     def rowHeight(self) -> int:
         """Return the height of a row."""
         return int((
@@ -176,7 +190,7 @@ class RibbonPanel(QtWidgets.QFrame):
         widget: QtWidgets.QWidget,
         rowSpan: int = 2,
         colSpan: int = 1,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ):
         """Add a widget to the panel.
@@ -201,7 +215,7 @@ class RibbonPanel(QtWidgets.QFrame):
     def addSmallWidget(
         self,
         widget: QtWidgets.QWidget,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ):
         """Add a small widget to the panel.
@@ -216,7 +230,7 @@ class RibbonPanel(QtWidgets.QFrame):
     def addMediumWidget(
         self,
         widget: QtWidgets.QWidget,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ):
         """Add a medium widget to the panel.
@@ -230,7 +244,7 @@ class RibbonPanel(QtWidgets.QFrame):
     def addLargeWidget(
         self,
         widget: QtWidgets.QWidget,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ):
         """Add a large widget to the panel.
@@ -257,14 +271,14 @@ class RibbonPanel(QtWidgets.QFrame):
         self,
         text: str = None,
         icon: QtGui.QIcon = None,
-        style: ButtonStyle = ButtonStyle.Large,
+        style: RibbonButtonStyle = RibbonButtonStyle.Large,
         showText: bool = True,
         colSpan: int = 1,
         slot=None,
         shortcut=None,
         tooltip=None,
         statusTip=None,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> RibbonToolButton:
         """Add a button to the panel.
@@ -305,7 +319,7 @@ class RibbonPanel(QtWidgets.QFrame):
             button.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
         self.addWidget(
             button,
-            rowSpan=2 if style == ButtonStyle.Small else 3 if style == ButtonStyle.Medium else 6,
+            rowSpan=2 if style == RibbonButtonStyle.Small else 3 if style == RibbonButtonStyle.Medium else 6,
             colSpan=colSpan,
             mode=mode,
             alignment=alignment
@@ -322,7 +336,7 @@ class RibbonPanel(QtWidgets.QFrame):
         shortcut=None,
         tooltip=None,
         statusTip=None,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> RibbonToolButton:
         """Add a small button to the panel.
@@ -338,7 +352,7 @@ class RibbonPanel(QtWidgets.QFrame):
         :param mode: The mode to find spaces.
         :param alignment: The alignment of the button.
         """
-        return self.addButton(text, icon, ButtonStyle.Small, showText, colSpan,
+        return self.addButton(text, icon, RibbonButtonStyle.Small, showText, colSpan,
                               slot, shortcut, tooltip, statusTip, mode, alignment)
 
     def addMediumButton(
@@ -351,7 +365,7 @@ class RibbonPanel(QtWidgets.QFrame):
         shortcut=None,
         tooltip=None,
         statusTip=None,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> RibbonToolButton:
         """Add a medium button to the panel.
@@ -367,7 +381,7 @@ class RibbonPanel(QtWidgets.QFrame):
         :param mode: The mode to find spaces.
         :param alignment: The alignment of the button.
         """
-        return self.addButton(text, icon, ButtonStyle.Medium, showText, colSpan,
+        return self.addButton(text, icon, RibbonButtonStyle.Medium, showText, colSpan,
                               slot, shortcut, tooltip, statusTip, mode, alignment)
 
     def addLargeButton(
@@ -380,7 +394,7 @@ class RibbonPanel(QtWidgets.QFrame):
         shortcut=None,
         tooltip=None,
         statusTip=None,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> RibbonToolButton:
         """Add a large button to the panel.
@@ -396,21 +410,21 @@ class RibbonPanel(QtWidgets.QFrame):
         :param mode: The mode to find spaces.
         :param alignment: The alignment of the button.
         """
-        return self.addButton(text, icon, ButtonStyle.Large, showText, colSpan,
+        return self.addButton(text, icon, RibbonButtonStyle.Large, showText, colSpan,
                               slot, shortcut, tooltip, statusTip, mode, alignment)
 
     def addToggleButton(
         self,
         text: str = None,
         icon: QtGui.QIcon = None,
-        style: ButtonStyle = ButtonStyle.Large,
+        style: RibbonButtonStyle = RibbonButtonStyle.Large,
         showText: bool = True,
         colSpan: int = 1,
         slot=None,
         shortcut=None,
         tooltip=None,
         statusTip=None,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> RibbonToolButton:
         """Add a toggle button to the panel.
@@ -442,7 +456,7 @@ class RibbonPanel(QtWidgets.QFrame):
         shortcut=None,
         tooltip=None,
         statusTip=None,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> RibbonToolButton:
         """Add a small toggle button to the panel.
@@ -459,7 +473,7 @@ class RibbonPanel(QtWidgets.QFrame):
         :param alignment: The alignment of the button.
         """
         return self.addToggleButton(
-            text, icon, ButtonStyle.Small, showText, colSpan, slot, shortcut, tooltip, statusTip, mode, alignment
+            text, icon, RibbonButtonStyle.Small, showText, colSpan, slot, shortcut, tooltip, statusTip, mode, alignment
         )
 
     def addMediumToggleButton(
@@ -472,7 +486,7 @@ class RibbonPanel(QtWidgets.QFrame):
         shortcut=None,
         tooltip=None,
         statusTip=None,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> RibbonToolButton:
         """Add a medium toggle button to the panel.
@@ -489,7 +503,7 @@ class RibbonPanel(QtWidgets.QFrame):
         :param alignment: The alignment of the button.
         """
         return self.addToggleButton(
-            text, icon, ButtonStyle.Medium, showText, colSpan, slot, shortcut, tooltip, statusTip, mode, alignment
+            text, icon, RibbonButtonStyle.Medium, showText, colSpan, slot, shortcut, tooltip, statusTip, mode, alignment
         )
 
     def addLargeToggleButton(
@@ -502,7 +516,7 @@ class RibbonPanel(QtWidgets.QFrame):
         shortcut=None,
         tooltip=None,
         statusTip=None,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> RibbonToolButton:
         """Add a large toggle button to the panel.
@@ -519,7 +533,7 @@ class RibbonPanel(QtWidgets.QFrame):
         :param alignment: The alignment of the button.
         """
         return self.addToggleButton(
-            text, icon, ButtonStyle.Large, showText, colSpan, slot, shortcut, tooltip, statusTip, mode, alignment
+            text, icon, RibbonButtonStyle.Large, showText, colSpan, slot, shortcut, tooltip, statusTip, mode, alignment
         )
 
     def addComboBox(
@@ -527,7 +541,7 @@ class RibbonPanel(QtWidgets.QFrame):
         items: typing.List[str],
         rowSpan: int = 2,
         colSpan: int = 1,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> QtWidgets.QComboBox:
         """Add a combo box to the panel.
@@ -547,7 +561,7 @@ class RibbonPanel(QtWidgets.QFrame):
         self,
         rowSpan: int = 2,
         colSpan: int = 1,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> QtWidgets.QFontComboBox:
         """Add a font combo box to the panel.
@@ -565,7 +579,7 @@ class RibbonPanel(QtWidgets.QFrame):
         self,
         rowSpan: int = 2,
         colSpan: int = 1,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> QtWidgets.QLineEdit:
         """Add a line edit to the panel.
@@ -583,7 +597,7 @@ class RibbonPanel(QtWidgets.QFrame):
         self,
         rowSpan: int = 2,
         colSpan: int = 1,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> QtWidgets.QTextEdit:
         """Add a text edit to the panel.
@@ -601,7 +615,7 @@ class RibbonPanel(QtWidgets.QFrame):
         self,
         rowSpan: int = 2,
         colSpan: int = 1,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> QtWidgets.QPlainTextEdit:
         """Add a plain text edit to the panel.
@@ -620,7 +634,7 @@ class RibbonPanel(QtWidgets.QFrame):
         text: str,
         rowSpan: int = 2,
         colSpan: int = 1,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> QtWidgets.QLabel:
         """Add a label to the panel.
@@ -640,7 +654,7 @@ class RibbonPanel(QtWidgets.QFrame):
         self,
         rowSpan: int = 2,
         colSpan: int = 1,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> QtWidgets.QProgressBar:
         """Add a progress bar to the panel.
@@ -658,7 +672,7 @@ class RibbonPanel(QtWidgets.QFrame):
         self,
         rowSpan: int = 2,
         colSpan: int = 1,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> QtWidgets.QSlider:
         """Add a slider to the panel.
@@ -677,7 +691,7 @@ class RibbonPanel(QtWidgets.QFrame):
         self,
         rowSpan: int = 2,
         colSpan: int = 1,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> QtWidgets.QSpinBox:
         """Add a spin box to the panel.
@@ -695,7 +709,7 @@ class RibbonPanel(QtWidgets.QFrame):
         self,
         rowSpan: int = 2,
         colSpan: int = 1,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> QtWidgets.QDoubleSpinBox:
         """Add a double spin box to the panel.
@@ -713,7 +727,7 @@ class RibbonPanel(QtWidgets.QFrame):
         self,
         rowSpan: int = 2,
         colSpan: int = 1,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> QtWidgets.QDateEdit:
         """Add a date edit to the panel.
@@ -731,7 +745,7 @@ class RibbonPanel(QtWidgets.QFrame):
         self,
         rowSpan: int = 2,
         colSpan: int = 1,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> QtWidgets.QTimeEdit:
         """Add a time edit to the panel.
@@ -749,7 +763,7 @@ class RibbonPanel(QtWidgets.QFrame):
         self,
         rowSpan: int = 2,
         colSpan: int = 1,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> QtWidgets.QDateTimeEdit:
         """Add a date time edit to the panel.
@@ -767,7 +781,7 @@ class RibbonPanel(QtWidgets.QFrame):
         self,
         rowSpan: int = 6,
         colSpan: int = 1,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> QtWidgets.QTableWidget:
         """Add a table widget to the panel.
@@ -785,7 +799,7 @@ class RibbonPanel(QtWidgets.QFrame):
         self,
         rowSpan: int = 6,
         colSpan: int = 1,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> QtWidgets.QTreeWidget:
         """Add a tree widget to the panel.
@@ -803,7 +817,7 @@ class RibbonPanel(QtWidgets.QFrame):
         self,
         rowSpan: int = 6,
         colSpan: int = 1,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> QtWidgets.QListWidget:
         """Add a list widget to the panel.
@@ -821,7 +835,7 @@ class RibbonPanel(QtWidgets.QFrame):
         self,
         rowSpan: int = 6,
         colSpan: int = 1,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> QtWidgets.QCalendarWidget:
         """Add a calendar widget to the panel.
@@ -841,7 +855,7 @@ class RibbonPanel(QtWidgets.QFrame):
         width=6,
         rowSpan: int = 6,
         colSpan: int = 1,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> typing.Union[RibbonHorizontalSeparator, RibbonVerticalSeparator]:
         """Add a separator to the panel.
@@ -864,7 +878,7 @@ class RibbonPanel(QtWidgets.QFrame):
         linewidth=6,
         rowSpan: int = 1,
         colSpan: int = 2,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> RibbonHorizontalSeparator:
         """Add a horizontal separator to the panel.
@@ -883,7 +897,7 @@ class RibbonPanel(QtWidgets.QFrame):
         linewidth=6,
         rowSpan: int = 6,
         colSpan: int = 1,
-        mode=SpaceFindMode.ColumnWise,
+        mode=RibbonSpaceFindMode.ColumnWise,
         alignment=QtCore.Qt.AlignCenter,
     ) -> RibbonVerticalSeparator:
         """Add a vertical separator to the panel.
@@ -903,7 +917,7 @@ class RibbonPanel(QtWidgets.QFrame):
         popupHideOnClick=False,
         rowSpan: int = 6,
         colSpan: int = 1,
-        mode=SpaceFindMode.ColumnWise
+        mode=RibbonSpaceFindMode.ColumnWise
     ) -> RibbonGallery:
         """Add a gallery to the panel.
 
